/*
 * $Id: date.h,v 1.6 1998/09/03 18:50:54 jochen Exp $
 * GXSNMP - An snmp managment application
 * Copyright (C) 1998 Gregory McLean
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 * 
 * Definitions for the date functions.
 */
#ifndef __DATE_FUNC_H_
#define __DATE_FUNC_H_

/*
 * Return a string all ready to be stuffed into a sql database.
 */
char          *db_time_str               (char *buf, int bufsize);

#endif

/* EOF */






